@@ -13,7 +13,7 @@ get_predicted.lmerMod <- function(x,
                                   verbose = TRUE,
                                   ...) {
   # Sanitize input
-  args <- .get_predicted_args(
+  my_args <- .get_predicted_args(
     x,
     data = data,
     predict = predict,
@@ -25,7 +25,7 @@ get_predicted.lmerMod <- function(x,
   )
 
   # Make prediction only using random if only random
-  if (all(names(args$data) %in% find_random(x, flatten = TRUE))) {
+  if (all(names(my_args$data) %in% find_random(x, flatten = TRUE))) {
     random.only <- TRUE
   } else {
     random.only <- FALSE
@@ -35,11 +35,11 @@ get_predicted.lmerMod <- function(x,
   predict_function <- function(x, ...) {
     stats::predict(
       x,
-      newdata = args$data,
-      type = args$type,
-      re.form = args$re.form,
+      newdata = my_args$data,
+      type = my_args$type,
+      re.form = my_args$re.form,
       random.only = random.only,
-      allow.new.levels = args$allow_new_levels,
+      allow.new.levels = my_args$allow_new_levels,
       ...
     )
   }
@@ -50,7 +50,7 @@ get_predicted.lmerMod <- function(x,
   } else {
     predictions <- .get_predicted_boot(
       x,
-      data = args$data,
+      data = my_args$data,
       predict_function = predict_function,
       iterations = iterations,
       verbose = verbose,
@@ -60,24 +60,22 @@ get_predicted.lmerMod <- function(x,
 
   # 2. step: confidence intervals
   ci_data <- get_predicted_ci(x, predictions,
-    data = args$data, ci = ci,
-    ci_method = ci_method, ci_type = args$ci_type,
+    data = my_args$data, ci = ci,
+    ci_method = ci_method, ci_type = my_args$ci_type,
     ...
   )
 
   # 3. step: back-transform
-  out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
+  out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose)
 
   # 4. step: final preparation
-  .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+  .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
 }
 
 #' @export
 get_predicted.merMod <- get_predicted.lmerMod
 
 
-
-
 # glmmTMB ---------------------------------------------------------------
 # =======================================================================
 
@@ -105,7 +103,7 @@ get_predicted.glmmTMB <- function(x,
   # https://bbolker.github.io/mixedmodels-misc/glmmFAQ.html#predictions-andor-confidence-or-prediction-intervals-on-predictions
 
   # Sanitize input
-  args <- .get_predicted_args(
+  my_args <- .get_predicted_args(
     x,
     data = data,
     predict = predict,
@@ -120,22 +118,22 @@ get_predicted.glmmTMB <- function(x,
     stats::predict(
       x,
       newdata = data,
-      type = args$type,
-      re.form = args$re.form,
-      allow.new.levels = args$allow_new_levels,
+      type = my_args$type,
+      re.form = my_args$re.form,
+      allow.new.levels = my_args$allow_new_levels,
       ...
     )
   }
 
   # 1. step: predictions
-  rez <- predict_function(x, data = args$data, se.fit = TRUE)
+  rez <- predict_function(x, data = my_args$data, se.fit = TRUE)
 
   if (is.null(iterations)) {
     predictions <- as.numeric(rez$fit)
   } else {
     predictions <- .get_predicted_boot(
       x,
-      data = args$data,
+      data = my_args$data,
       predict_function = predict_function,
       iterations = iterations,
       verbose = verbose,
@@ -146,16 +144,16 @@ get_predicted.glmmTMB <- function(x,
   # "expectation" for zero-inflated? we need a special handling
   # for predictions and CIs here.
 
-  if (args$scale == "response" && args$info$is_zero_inflated) {
+  if (my_args$scale == "response" && my_args$info$is_zero_inflated) {
     # intermediate step: prediction from ZI model, for non-truncated families!
     # for truncated family, behaviour in glmmTMB changed in 1.1.5  to correct
     # conditional and response predictions
-    if (!args$info$is_hurdle) {
+    if (!my_args$info$is_hurdle) {
       zi_predictions <- stats::predict(
         x,
         newdata = data,
         type = "zprob",
-        re.form = args$re.form,
+        re.form = my_args$re.form,
         ...
       )
       predictions <- link_inverse(x)(predictions) * (1 - as.vector(zi_predictions))
@@ -183,16 +181,14 @@ get_predicted.glmmTMB <- function(x,
     )
 
     # 3. step: back-transform
-    out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
+    out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose)
   }
 
   # 4. step: final preparation
-  .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+  .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
 }
 
 
-
-
 # GLMMadaptive: mixed_model (class MixMod) ------------------------------
 # =======================================================================
 
@@ -217,7 +213,7 @@ get_predicted.MixMod <- function(x,
   }
 
   # Sanitize input
-  args <- .get_predicted_args(
+  my_args <- .get_predicted_args(
     x,
     data = data,
     predict = predict,
@@ -232,21 +228,21 @@ get_predicted.MixMod <- function(x,
     stats::predict(
       x,
       newdata = data,
-      type_pred = args$type,
-      type = ifelse(isTRUE(args$include_random), "subject_specific", "mean_subject"),
+      type_pred = my_args$type,
+      type = ifelse(isTRUE(my_args$include_random), "subject_specific", "mean_subject"),
       ...
     )
   }
 
   # 1. step: predictions
-  rez <- predict_function(x, data = args$data)
+  rez <- predict_function(x, data = my_args$data)
 
   if (is.null(iterations)) {
     predictions <- as.numeric(rez)
   } else {
     predictions <- .get_predicted_boot(
       x,
-      data = args$data,
+      data = my_args$data,
       predict_function = predict_function,
       iterations = iterations,
       verbose = verbose,
@@ -257,7 +253,7 @@ get_predicted.MixMod <- function(x,
   # "expectation" for zero-inflated? we need a special handling
   # for predictions and CIs here.
 
-  if (args$scale == "response" && args$info$is_zero_inflated) {
+  if (my_args$scale == "response" && my_args$info$is_zero_inflated) {
     # 2. and 3. step: confidence intervals and back-transform
     ci_data <- .simulate_zi_predictions(model = x, newdata = data, predictions = predictions, nsim = iterations, ci = ci)
     out <- list(predictions = predictions, ci_data = ci_data)
@@ -266,22 +262,21 @@ get_predicted.MixMod <- function(x,
     ci_data <- get_predicted_ci(
       x,
       predictions,
-      data = args$data[colnames(args$data) != find_response(x)],
+      data = my_args$data[colnames(my_args$data) != find_response(x)],
       ci = ci,
-      ci_type = args$ci_type,
+      ci_type = my_args$ci_type,
       ...
     )
 
     # 3. step: back-transform
-    out <- .get_predicted_transform(x, predictions, args, ci_data)
+    out <- .get_predicted_transform(x, predictions, my_args, ci_data)
   }
 
   # 4. step: final preparation
-  .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+  .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
 }
 
 
-
 # HGLM: mixed_model (class hglm) ------------------------------
 # =============================================================
 
