@@ -58,7 +58,6 @@ get_statistic <- function(x, ...) {
 }
 
 
-
 # Default models ----------------------------------------------------------
 
 
@@ -210,6 +209,22 @@ get_statistic.asym <- function(x, ...) {
 }
 
 
+#' @export
+get_statistic.oohbchoice <- function(x, ...) {
+  cftable <- summary(x)$coef
+  out <- data.frame(
+    Parameter = find_parameters(x)$conditional,
+    Statistic = cftable[, "z value"],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.afex_aov <- function(x, ...) {
   out <- data.frame(
@@ -270,7 +285,6 @@ get_statistic.negbin <- get_statistic.default
 get_statistic.feis <- get_statistic.default
 
 
-
 # Models with zero-inflation component --------------------------------------
 
 
@@ -610,7 +624,6 @@ get_statistic.cgam <- function(x, component = "all", ...) {
 }
 
 
-
 # Survival models ------------------------------------------
 
 
@@ -777,7 +790,6 @@ get_statistic.aareg <- function(x, ...) {
 }
 
 
-
 # Ordinal models --------------------------------------------------
 
 
@@ -1072,7 +1084,6 @@ get_statistic.mblogit <- function(x, ...) {
 }
 
 
-
 # mfx models -------------------------------------------------------
 
 #' @export
@@ -1549,8 +1560,8 @@ get_statistic.mipo <- function(x, ...) {
     stringsAsFactors = FALSE
   )
   # check for ordinal-alike models
-  if ("y.level" %in% colnames(s)) {
-    params$Response <- as.vector(s$y.level)
+  if (!is.null(x$pooled) && "y.level" %in% colnames(x$pooled)) {
+    params$Response <- as.vector(x$pooled$y.level)
   }
   out <- text_remove_backticks(params)
   attr(out, "statistic") <- find_statistic(x)
@@ -1760,7 +1771,6 @@ get_statistic.averaging <- function(x, component = "conditional", ...) {
 }
 
 
-
 #' @export
 get_statistic.bayesx <- function(x, ...) {
   out <- data.frame(
@@ -1791,7 +1801,6 @@ get_statistic.Arima <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.wbm <- function(x, ...) {
   s <- summary(x)
@@ -1830,7 +1839,6 @@ get_statistic.wbm <- function(x, ...) {
 get_statistic.wbgee <- get_statistic.wbm
 
 
-
 #' @export
 get_statistic.cpglmm <- function(x, ...) {
   check_if_installed("cplm")
@@ -1894,7 +1902,6 @@ get_statistic.cpglm <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.zcpglm <- function(x, component = "all", ...) {
   check_if_installed("cplm")
@@ -1927,7 +1934,6 @@ get_statistic.zcpglm <- function(x, component = "all", ...) {
 }
 
 
-
 #' @export
 get_statistic.manova <- function(x, ...) {
   stats <- as.data.frame(summary(x)$stats)
@@ -1944,7 +1950,6 @@ get_statistic.manova <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.maov <- function(x, ...) {
   s <- summary(x)
@@ -1965,7 +1970,6 @@ get_statistic.maov <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.MANOVA <- function(x, ...) {
   stats <- as.data.frame(x$WTS)
@@ -1985,7 +1989,6 @@ get_statistic.MANOVA <- function(x, ...) {
 get_statistic.RM <- get_statistic.MANOVA
 
 
-
 #' @export
 get_statistic.rq <- function(x, ...) {
   stat <- tryCatch(
@@ -2075,7 +2078,6 @@ get_statistic.crqs <- get_statistic.crq
 get_statistic.nlrq <- get_statistic.rq
 
 
-
 #' @export
 get_statistic.rqss <- function(x,
                                component = c("all", "conditional", "smooth_terms"),
@@ -2104,7 +2106,6 @@ get_statistic.rqss <- function(x,
 }
 
 
-
 #' @export
 get_statistic.systemfit <- function(x, ...) {
   cf <- stats::coef(summary(x))
@@ -2131,7 +2132,6 @@ get_statistic.systemfit <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.bigglm <- function(x, ...) {
   parms <- get_parameters(x)
@@ -2150,7 +2150,6 @@ get_statistic.bigglm <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.biglm <- function(x, ...) {
   parms <- get_parameters(x)
@@ -2199,6 +2198,15 @@ get_statistic.fixest <- function(x, ...) {
   cs <- summary(x)$coeftable
   params <- get_parameters(x)
 
+  # remove .theta row
+  rn <- rownames(cs)
+  if (!is.null(rn)) {
+    theta_row <- which(rn == ".theta")
+    if (length(theta_row)) {
+      cs <- cs[-theta_row, ]
+    }
+  }
+
   out <- data.frame(
     Parameter = params$Parameter,
     Statistic = as.vector(cs[, 3]),
