@@ -10,6 +10,11 @@
 #' are nested, also returns two attributes that indicate whether nesting of
 #' models is in decreasing or increasing order.
 #'
+#' @details The term "nested" here means that all the fixed predictors of a
+#' model are contained within the fixed predictors of a larger model (sometimes
+#' referred to as the encompassing model). Currently, `is_nested_models()` ignores
+#' random effects parameters.
+#'
 #' @examples
 #' m1 <- lm(Sepal.Length ~ Petal.Width + Species, data = iris)
 #' m2 <- lm(Sepal.Length ~ Species, data = iris)
@@ -21,14 +26,14 @@
 #' is_nested_models(m1, m2, m3)
 #' @export
 is_nested_models <- function(...) {
-  objects <- list(...)
-  object_names <- match.call(expand.dots = FALSE)$`...`
+  model_objects <- list(...)
+  object_names <- match.call(expand.dots = FALSE)[["..."]]
 
-  if (!all(sapply(objects, is_regression_model))) {
-    stop("All models must be valid regression model objects.", call. = FALSE)
+  if (!all(vapply(model_objects, is_regression_model, TRUE))) {
+    format_error("All models must be valid regression model objects.")
   }
-  names(objects) <- object_names
-  info <- ellipsis_info.ListRegressions(objects)
+  names(model_objects) <- object_names
+  info <- ellipsis_info.ListRegressions(model_objects)
 
   out <- isTRUE(attributes(info)$is_nested)
   attr(out, "is_nested_increasing") <- attributes(info)$is_nested_increasing
